# ELFIO

![C/C++ CI](https://github.com/serge1/ELFIO/workflows/C/C++%20CI/badge.svg)
![CodeQL](https://github.com/serge1/ELFIO/workflows/CodeQL/badge.svg)
[![Documentation](https://img.shields.io/badge/doc-download-brightgreen)](http://elfio.sourceforge.net/elfio.pdf)
[![License](https://img.shields.io/badge/License-MIT-brightgreen.svg)](https://github.com/serge1/ELFIO/blob/master/COPYING)

ELFIO is a header-only C++ library intended for reading and generating
files in the ELF binary format. It is used as a standalone library - it is not
dependent on any other product or project. Adhering to ISO C++, it compiles on
a wide variety of architectures and compilers.

While written in C++, the library also provides a C-language interface wrapper.

The full library documentation can be found in *[ELFIO - Tutorial and User Manual](http://elfio.sourceforge.net/elfio.pdf)*.
